@@ -1,4 +1,4 @@
-/*$Id: Rules.cpp,v 1.6 2007/02/13 00:11:14 jwrobel Exp $*/
+/*$Id: Rules.cpp,v 1.7 2007/03/23 11:49:03 jwrobel Exp $*/
 /* ***** BEGIN LICENSE BLOCK *****
  *  This file is part of Firekeeper.
  *
@@ -34,7 +34,7 @@ Rules::Rules()
 /*call after constructor*/
 int Rules::init()
 {
-	TRACE("initializing rules (%d types known)", sizeof(knownActions));
+	TRACE("initializing rules (%d types known)", sizeof(knownActions) / sizeof(char *));
 	noContentRules.clear();
 
 	if (searchAPI->search_init(sizeof(knownActions) / sizeof(char *)) < 0)
